@@ -47,7 +47,7 @@ private slots:
     void LoadConfig();
     void SaveConfig();
     void LoadVoice();
-    QString GetSound(QString distance, QString linkID, QString maneuverType, QString turnVal);
+    QString GetSound(QString distance, QString unit, QString linkID, QString maneuverType, QString turnVal);
 };
 
 #endif // MAINWINDOW_H
